# Research Summary

## Topic
- {topic}

## Goal
- {goal}

## Key Findings
- {finding_1}
- {finding_2}

## Recommended Principles
- {principle_1}
- {principle_2}

## Sources
1. {source_title} — {source_url}
2. {source_title} — {source_url}

## Uncertainties
- {uncertainty_or_none}
